@@ -20,6 +20,38 @@ sub new {
 		Wx::wxDefaultSize,
 		Wx::wxDEFAULT_FRAME_STYLE | Wx::wxTAB_TRAVERSAL,
 	);
+	$self->CreateStatusBar( 2, Wx::wxST_SIZEGRIP, -1 );
+
+	$self->{m_menu1} = Wx::Menu->new;
+
+	my $m_menuItem1 = Wx::MenuItem->new(
+		$self->{m_menu1},
+		-1,
+		Wx::gettext("MyMenuItem"),
+		'',
+		Wx::wxITEM_NORMAL,
+	);
+
+	my $m_menuItem2 = Wx::MenuItem->new(
+		$self->{m_menu1},
+		-1,
+		Wx::gettext("MyMenuItem"),
+		'',
+		Wx::wxITEM_NORMAL,
+	);
+
+	$self->{m_menu1}->Append( $m_menuItem1 );
+	$self->{m_menu1}->AppendSeparator;
+	$self->{m_menu1}->Append( $m_menuItem2 );
+
+	$self->{m_menubar1} = Wx::MenuBar->new(0);
+
+	$self->{m_menubar1}->Append(
+		$self->{m_menu1},
+		Wx::gettext("File"),
+	);
+
+	$self->SetMenuBar( $self->{m_menubar1} );
 
 	$self->{m_staticText5} = Wx::StaticText->new(
 		$self,
@@ -33,12 +65,6 @@ sub new {
 		Wx::gettext("MyButton"),
 	);
 
-	$self->CreateStatusBar(
-		2,
-		Wx::wxST_SIZEGRIP,
-		-1,
-	);
-
 	my $bSizer7 = Wx::BoxSizer->new(Wx::wxHORIZONTAL);
 	$bSizer7->Add( $self->{m_staticText5}, 0, Wx::wxALIGN_CENTER_VERTICAL | Wx::wxALL, 5 );
 	$bSizer7->Add( $self->{m_button4}, 0, Wx::wxALL, 5 );
